/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.exception;

import com.cloudwords.api.client.resources.Error;

/**
 * Base class for exceptions that occur during the client usage.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class CloudwordsClientException extends Exception {

    private static final long serialVersionUID = 1L;
    private Integer httpStatusCode = null;

    public CloudwordsClientException(String errorMessage) {
        super(errorMessage);
    }

    public CloudwordsClientException(Error error) {
        super(error.getError());
        this.httpStatusCode = error.getHttpStatusCode();
    }

    public CloudwordsClientException(Exception ex) {
        super(ex);
    }

    public CloudwordsClientException(Error error, Exception ex) {
        super(error.getError(), ex);
        this.httpStatusCode = error.getHttpStatusCode();
    }

    /**
     * The associated HTTP status code that accompanied this Exception, if any. Please refer to the
     * API documentation for more information about HTTP status codes.
     * 
     * @return The associated HTTP status code that accompanied this Exception, if any.
     */
    public Integer getHttpStatusCode() {
        return httpStatusCode;
    }

}
