/*
 * Copyright 2012, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;

/**
 * Represents a {@link BaseProject} resource in Cloudwords. A {@link BaseProject} is the central resource in Cloudwords,
 * as it represents an initiative to translate some content. It contains information, both necessary and optional, to
 * define a {@link BaseProject}'s requirements, such as the content's source {@link Language} and requested target
 * {@link Language}s to translate into.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class BaseProject extends BaseResource {

    private int id;
    private String name;

    /**
     * Get the Cloudwords ID of this {@link BaseProject}.
     * 
     * @return ID of this {@link BaseProject}
     */
    public int getId() {
        return id;
    }

    /**
     * Set the Cloudwords ID of this {@link BaseProject}.
     * 
     * @param id
     *            of this {@link BaseProject}
     */
    public void setId(int id) {
        this.id = id;
    }

    /**
     * Get the {@link BaseProject} name.
     * 
     * @return name of this {@link BaseProject}
     */
    public String getName() {
        return name;
    }

    /**
     * Set the {@link BaseProject} name.
     * 
     * @param name
     *            of this {@link BaseProject}
     */
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(id).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) { return false; }
        if (obj == this) { return true; }
        if (obj.getClass() != getClass()) { return false; }
        BaseProject rhs = (BaseProject)obj;
        return new EqualsBuilder().append(id, rhs.id).isEquals();
    }

}
