/**
 * 
 */
package com.cloudwords.api.client.resources;

import java.util.Set;

/**
 * Represents a {@link Language} specific bid item provided by a {@link Vendor} for a given Cloudwords
 * {@link Project}.
 * 
 * @author jonathansu
 * @since 1.7
 */
public class BidItem extends BaseResource {

    private Integer id;
    private Set<BidItemTask> bidItemTasks;
    private Language language;
    private Boolean isLanguageRemoved;
    
    /**
     * Get the unique ID associated with this {@link BidItem}
     * @return The unique ID associated with this {@link BidItem}
     */
    public Integer getId() {
        return id;
    }
    
    /**
     * Set the unique ID associated with this {@link BidItem}
     * @param id The unique ID associated with this {@link BidItem}
     */
    public void setId(Integer id) {
        this.id = id;
    }
    
    /**
     * Get the cost breakdown of this {@link BidItem} provided by 
     * {@link Vendor} for each {@link BidItemTask}
     * @return The cost breakdown of this {@link BidItem} provided by 
     * {@link Vendor} for each {@link BidItemTask}
     */
    public Set<BidItemTask> getBidItemTasks() {
        return bidItemTasks;
    }
    
    /**
     * Set the cost breakdown of this {@link BidItem} provided by 
     * {@link Vendor} for each {@link BidItemTask}
     * @param bidItemTasks The cost breakdown of this {@link BidItem} provided by 
     * {@link Vendor} for each {@link BidItemTask}
     */
    public void setBidItemTasks(Set<BidItemTask> bidItemTasks) {
        this.bidItemTasks = bidItemTasks;
    }
    
    /**
     * The {@link Language} this {@link BidItem} is associated with
     * @return The {@link Language} this {@link BidItem} is associated with
     */
    public Language getLanguage() {
        return language;
    }
    
    /**
     * Set the {@link Language} this {@link BidItem} is associated with
     * @param language The {@link Language} this {@link BidItem} is associated with
     */
    public void setLanguage(Language language) {
        this.language = language;
    }
    
    /**
     * Whether this {@link BidItem} is for a {@link Language} that the {@link Customer}
     * has decided to remove for a given {@link Project}
     * @return Whether this {@link BidItem} is for a {@link Language} that the {@link Customer}
     * has decided to remove for a given {@link Project}
     */
    public Boolean getIsLanguageRemoved() {
        return isLanguageRemoved;
    }
    
    /**
     * Set whether this {@link BidItem} is for a {@link Language} that the {@link Customer}
     * has decided to remove for a given {@link Project}
     * @param isLanguageRemoved Whether this {@link BidItem} is for a {@link Language} 
     * has the {@link Customer} have decided to remove for a given {@link Project}
     */
    public void setIsLanguageRemoved(Boolean isLanguageRemoved) {
        this.isLanguageRemoved = isLanguageRemoved;
    }    
    
}
