package com.cloudwords.api.client.resources;

import java.util.Date;
import java.util.List;

/**
 * A {@link ChangeOrder} is a request to alter the {@link Project} requirements, such as adding languages, files, or both, after the
 * project has been assigned to a specific vendor and translation is underway. Since these changes affect a vendor's
 * bid, they must be requested by you, quoted by the provider, and approved by you in a similar manner to what happens
 * when you first requested bids for the project.
 * 
 * @author cchandr
 * @since 1.12.1
 */
public class ChangeOrder extends BaseResource {

    private Integer id;

    private String name;

    private BaseProject project;

    private Date createdDate;

    private String description;

    private String rejectionDescription;

    private List<Language> languagesToAdd;

    private List<Language> languagesToRemove;

    private CodeAndDisplay status;

    /**
     * Get the Cloudwords {@link ChangeOrder} id
     * @return Returns the id.
     */
    public Integer getId() {
        return id;
    }
    
    /**
     * Set the Cloudwords {@link ChangeOrder} name.
     * @param id The id to set.
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} name
     * @return Returns the name.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the Cloudwords {@link ChangeOrder} name.
     * @param name The name to set.
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} project
     * @return Returns the project.
     */
    public BaseProject getProject() {
        return project;
    }
    
    /**
     * Sets the Cloudwords {@link ChangeOrder} project.
     * @param project The project to set.
     */
    public void setProject(BaseProject project) {
        this.project = project;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} createdDate
     * @return Returns the createdDate.
     */
    public Date getCreatedDate() {
        return createdDate;
    }
    
    /**
     * Sets the Cloudwords {@link ChangeOrder} createdDate
     * @param createdDate The createdDate to set.
     */
    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} description
     * @return Returns the description.
     */
    public String getDescription() {
        return description;
    }

    /**
     * Set the Cloudwords {@link ChangeOrder} description.
     * @param description The description to set.
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} rejection description
     * @return Returns the rejectionDescription.
     */
    public String getRejectionDescription() {
        return rejectionDescription;
    }

    /**
     * Set the Cloudwords {@link ChangeOrder} rejection description.
     * @param rejectionDescription The rejectionDescription to set.
     */
    public void setRejectionDescription(String rejectionDescription) {
        this.rejectionDescription = rejectionDescription;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} list of languages to add
     * @return Returns the languagesToAdd.
     */
    public List<Language> getLanguagesToAdd() {
        return languagesToAdd;
    }

    /**
     * Set the Cloudwords {@link ChangeOrder} languages to add list.
     * @param languagesToAdd The languagesToAdd to set.
     */
    public void setLanguagesToAdd(List<Language> languagesToAdd) {
        this.languagesToAdd = languagesToAdd;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} languages to remove list.
     * @return Returns the languagesToRemove.
     */
    public List<Language> getLanguagesToRemove() {
        return languagesToRemove;
    }

    /**
     * Set the Cloudwords {@link ChangeOrder} languages to remove list.
     * @param languagesToRemove The languagesToRemove to set.
     */
    public void setLanguagesToRemove(List<Language> languagesToRemove) {
        this.languagesToRemove = languagesToRemove;
    }

    /**
     * Get the Cloudwords {@link ChangeOrder} status.
     * @return Returns the status.
     */
    public CodeAndDisplay getStatus() {
        return status;
    }

    /**
     * Set the Cloudwords {@link ChangeOrder} status.
     * @param status The status to set.
     */
    public void setStatus(CodeAndDisplay status) {
        this.status = status;
    }
}
