/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.resources;

import java.util.List;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents {@link Customer}'s view of a bid provided by a {@link Vendor} 
 * for a given Cloudwords {@link Project}.
 * 
 * @author syancey
 * @since 1.1
 */
public class CustomerBid extends BidSummary {

    private Vendor vendor;
    private List<BidItem> bidItems;
    
    /**
     * Get the {@link Vendor} associated with this {@link CustomerBid}
     * @return The {@link Vendor} associated with this {@link CustomerBid}
     */
    public Vendor getVendor() {
        return vendor;
    }

    /**
     * Set the {@link Vendor} associated with this {@link CustomerBid}
     * @param vendor {@link Vendor} associated with this {@link CustomerBid}
     */
    public void setVendor(Vendor vendor) {
        this.vendor = vendor;
    }
    
    /**
     * Get the {@link BidItem} provided by the {@link Vendor} for this bid
     * @return The {@link BidItem} provided by the {@link Vendor} for this bid
     */
    public List<BidItem> getBidItems() {
        return bidItems;
    }

    /**
     * Set the {@link BidItem} provided by the {@link Vendor} for this bid
     * @param bidItems Set the {@link BidItem} provided by the {@link Vendor} for this bid
     */
    public void setBidItems(List<BidItem> bidItems) {
        this.bidItems = bidItems;
    }
    
    @Override
    public String toString() {
        return new ToStringBuilder(this).append("id", getId()).append("vendor", vendor).append("status", getStatus())
                .append("description", getDescription()).append("amount", getAmount()).append("path", getPath()).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(getId()).append(vendor).append(getStatus()).append(getDescription()).append(getAmount())
                .append(getPath()).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        CustomerBid rhs = (CustomerBid)obj;
        return new EqualsBuilder().append(getId(), rhs.getId()).append(vendor, rhs.vendor).append(getStatus(), rhs.getStatus())
                .append(getDescription(), rhs.getDescription()).append(getAmount(), rhs.getAmount()).append(getPath(), rhs.getPath()).isEquals();
    }

}
