/*
d * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents a {@link Project}'s {@link IntendedUse} use in Cloudwords. An {@link IntendedUse}
 * represents what purpose a given {@link Project}'s content is intended for (e.g. Website, Product,
 * Legal, etc.).
 * 
 * @author jonathansu
 * @since 1.0
 */
public class IntendedUse {

    private int id;
    private String name;


    /**
     * Get the Cloudwords {@link IntendedUse} ID.
     * 
     * @return id of this {@link IntendedUse}
     */
    public int getId() {
        return id;
    }

    /**
     * Set the Cloudwords {@link IntendedUse} ID.
     * 
     * @param id
     *            of this {@link IntendedUse}
     */
    public void setId(int id) {
        this.id = id;
    }

    /**
     * Get the name of this {@link IntendedUse}.
     * 
     * @return name of this {@link IntendedUse}
     */
    public String getName() {
        return name;
    }

    /**
     * Set the name of this {@link IntendedUse}.
     * 
     * @param name
     *            of this {@link IntendedUse}
     */
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("id", id).append("name", name).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(id).append(name).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        IntendedUse rhs = (IntendedUse)obj;
        return new EqualsBuilder().append(id, rhs.id).append(name, rhs.name).isEquals();
    }
}
