/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents a {@link Language} resource in Cloudwords.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class Language {

    private String display;
    private String languageCode;

    public Language() {
        this(null);
    }

    public Language(String languageCode) {
        if (languageCode != null && languageCode.trim().length() > 0)
            this.languageCode = languageCode;
    }

    /**
     * Get the user-friendly display representation of this {@link Language}.
     * 
     * @return user-friendly display
     */
    public String getDisplay() {
        return display;
    }

    /**
     * Set the user-friendly display representation of this {@link Language}.
     * 
     * @param display
     *            user-friendly display
     */
    public void setDisplay(String display) {
        this.display = display;
    }

    /**
     * Get the Cloudwords {@link Language} code for this {@link Language}.
     * 
     * @return Cloudwords {@link Language} code
     */
    public String getLanguageCode() {
        return languageCode;
    }

    /**
     * Set the Cloudwords {@link Language} code for this {@link Language}.
     * 
     * @param languageCode
     *            Cloudwords {@link Language} code
     */
    public void setLanguageCode(String languageCode) {
        this.languageCode = languageCode;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("display", display).append("languageCode", languageCode).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(display).append(languageCode).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        Language rhs = (Language)obj;
        return new EqualsBuilder().append(display, rhs.display).append(languageCode, rhs.languageCode).isEquals();
    }

}
