/*
 * Copyright 2014, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

import java.util.Date;
import java.util.List;

/**
 * A single phase of a workflow, phases are grouped into steps. Phases execute in order
 * according to their phase number within a step. Each step will have a phase 1, 2, etc...
 * Certain actions, such as a revision request, may cause a workflow to jump back to a 
 * previous phase.
 * 
 * @author amadigan
 * @since 1.12.2
 */
public class ProjectWorkflowPhase extends BaseResource {
    private int phaseNumber;
    private CodeAndDisplay assigneeType;
    private CodeAndDisplay phaseType;
    private boolean allowRevision;
    private Assignee assignee;
    private Date dueDate;
    private List<Assignee> possibleAssignees;

    public int getPhaseNumber() {
        return phaseNumber;
    }

    public void setPhaseNumber(int phaseNumber) {
        this.phaseNumber = phaseNumber;
    }

    public boolean isAllowRevision() {
        return allowRevision;
    }

    public void setAllowRevision(boolean allowRevision) {
        this.allowRevision = allowRevision;
    }

    public Assignee getAssignee() {
        return assignee;
    }

    public void setAssignee(Assignee assignee) {
        this.assignee = assignee;
    }

    public Date getDueDate() {
        return dueDate;
    }

    public void setDueDate(Date dueDate) {
        this.dueDate = dueDate;
    }

    @Override
    public String toString() {
        return "ProjectWorkflowPhase [phaseNumber=" + phaseNumber + ", assigneeType=" + assigneeType + ", phaseType="
                + phaseType + ", allowRevision=" + allowRevision + ", assignee=" + assignee + ", dueDate=" + dueDate
                + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + (allowRevision ? 1231 : 1237);
        result = prime * result + ((assignee == null) ? 0 : assignee.hashCode());
        result = prime * result + ((assigneeType == null) ? 0 : assigneeType.hashCode());
        result = prime * result + ((dueDate == null) ? 0 : dueDate.hashCode());
        result = prime * result + phaseNumber;
        result = prime * result + ((phaseType == null) ? 0 : phaseType.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
        if (getClass() != obj.getClass()) return false;
        ProjectWorkflowPhase other = (ProjectWorkflowPhase)obj;
        if (allowRevision != other.allowRevision) return false;
        if (assignee == null) {
            if (other.assignee != null) return false;
        } else if (!assignee.equals(other.assignee)) return false;
        if (assigneeType == null) {
            if (other.assigneeType != null) return false;
        } else if (!assigneeType.equals(other.assigneeType)) return false;
        if (dueDate == null) {
            if (other.dueDate != null) return false;
        } else if (!dueDate.equals(other.dueDate)) return false;
        if (phaseNumber != other.phaseNumber) return false;
        if (phaseType == null) {
            if (other.phaseType != null) return false;
        } else if (!phaseType.equals(other.phaseType)) return false;
        return true;
    }

    public List<Assignee> getPossibleAssignees() {
        return possibleAssignees;
    }

    public void setPossibleAssignees(List<Assignee> possibleAssignees) {
        this.possibleAssignees = possibleAssignees;
    }

    public CodeAndDisplay getAssigneeType() {
        return assigneeType;
    }

    public void setAssigneeType(CodeAndDisplay assigneeType) {
        this.assigneeType = assigneeType;
    }

    public CodeAndDisplay getPhaseType() {
        return phaseType;
    }

    public void setPhaseType(CodeAndDisplay phaseType) {
        this.phaseType = phaseType;
    }

}
