/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents a {@link Vendor} resource in Cloudwords. A {@link Vendor} is assigned to a Cloudwords
 * {@link Project} in order to provide the necessary translation services.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class Vendor {

    private int id;
    private String name;
    private String path;
    private boolean requiresBidding;

    /**
     * Get the Cloudwords {@link Vendor} ID.
     * 
     * @return id of this {@link Vendor}
     */
    public int getId() {
        return id;
    }

    /**
     * Set the Cloudwords {@link Vendor} ID.
     * 
     * @param id
     *          ID of this {@link Vendor}
     */
    public void setId(int id) {
        this.id = id;
    }

    /**
     * Get the {@link Vendor} name
     * 
     * @return name of this {@link Vendor}
     */
    public String getName() {
        return name;
    }

    /**
     * Set the {@link Vendor} name.
     * 
     * @param name
     *            of this {@link Vendor}
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Get the API-accessible path to this {@link Vendor}. This is the HTTP accessible path to
     * perform a GET on the {@link Vendor}. Please refer to the API documentation for more detail.
     * 
     * @return path of this {@link Vendor}
     */
    public String getPath() {
        return path;
    }
    
    /**
     * Gets whether this preferred {@link Vendor} is required to submit bid before translations can proceed. Please refer to the API 
     * documentation for more detail.
     * @return true : Requires bidding to occur before translation is requested
     *         false: Bid submissions isn't mandatory for the vendor. Customers can request translations without having the preferred vendor submit quotes.
     */
    public boolean isRequiresBidding() {
        return requiresBidding;
    }

    /**
     * Set whether this {@link Vendor} requires bidding or not.
     * @param requiresBidding Whether or not this project requires bidding.
     */
    public void setRequiresBidding(boolean requiresBidding) {
        this.requiresBidding = requiresBidding;
    }

    /**
     * Set the API-accessible path to this {@link Vendor}. (Note: The path is a read-only field with
     * Cloudwords API - Cloudwords will automatically calculate the API-accessible path on any
     * project representation returned from the API).
     * 
     * @param path
     *            Path to this {@link Vendor}
     */
    public void setPath(String path) {
        this.path = path;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("id", id).append("name", name).append("path", path).append("requiresBidding", requiresBidding).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(id).append(name).append(path).append(requiresBidding).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        Vendor rhs = (Vendor)obj;
        return new EqualsBuilder().append(id, rhs.id).append(name, rhs.name).append(path, rhs.path).append(requiresBidding, rhs.requiresBidding).isEquals();
    }

}
