/*
 * Copyright 2014, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

/**
 * A single phase of a workflow, phases are grouped into steps. Phases execute in order
 * according to their phase number within a step. Each step will have a phase 1, 2, etc...
 * Certain actions, such as a revision request, may cause a workflow to jump back to a 
 * previous phase.
 * 
 * @author amadigan
 * @since 1.12.2
 */
public class WorkflowTemplatePhase extends BaseResource {
    private int phaseNumber;
    private CodeAndDisplay assigneeType;
    private CodeAndDisplay phaseType;
    private boolean allowRevision;
    private Integer durationInDays;

    public int getPhaseNumber() {
        return phaseNumber;
    }

    public void setPhaseNumber(int phaseNumber) {
        this.phaseNumber = phaseNumber;
    }

    public boolean isAllowRevision() {
        return allowRevision;
    }

    public void setAllowRevision(boolean allowRevision) {
        this.allowRevision = allowRevision;
    }

    public Integer getDurationInDays() {
        return durationInDays;
    }

    public void setDurationInDays(Integer durationInDays) {
        this.durationInDays = durationInDays;
    }

    @Override
    public String toString() {
        return "WorkflowTemplatePhase [phaseNumber=" + phaseNumber + ", assigneeType=" + assigneeType + ", phaseType="
                + phaseType + ", allowRevision=" + allowRevision + ", durationInDays=" + durationInDays + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + (allowRevision ? 1231 : 1237);
        result = prime * result + ((assigneeType == null) ? 0 : assigneeType.hashCode());
        result = prime * result + ((durationInDays == null) ? 0 : durationInDays.hashCode());
        result = prime * result + phaseNumber;
        result = prime * result + ((phaseType == null) ? 0 : phaseType.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
        if (getClass() != obj.getClass()) return false;
        WorkflowTemplatePhase other = (WorkflowTemplatePhase)obj;
        if (allowRevision != other.allowRevision) return false;
        if (assigneeType == null) {
            if (other.assigneeType != null) return false;
        } else if (!assigneeType.equals(other.assigneeType)) return false;
        if (durationInDays == null) {
            if (other.durationInDays != null) return false;
        } else if (!durationInDays.equals(other.durationInDays)) return false;
        if (phaseNumber != other.phaseNumber) return false;
        if (phaseType == null) {
            if (other.phaseType != null) return false;
        } else if (!phaseType.equals(other.phaseType)) return false;
        return true;
    }

    public CodeAndDisplay getAssigneeType() {
        return assigneeType;
    }

    public void setAssigneeType(CodeAndDisplay assigneeType) {
        this.assigneeType = assigneeType;
    }

    public CodeAndDisplay getPhaseType() {
        return phaseType;
    }

    public void setPhaseType(CodeAndDisplay phaseType) {
        this.phaseType = phaseType;
    }

}
