/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.serializers;

import java.io.IOException;

import com.cloudwords.api.client.resources.Language;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;

/**
 * Serializes {@link Language} into Cloudwords API input format.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class LanguageSerializer extends JsonSerializer<Language> {

    @Override
    public void serialize(Language value, JsonGenerator jgen, SerializerProvider provider) throws IOException,
            JsonProcessingException {
        if (value == null) {
            throw new JsonMappingException("Unable to serialize Language into JSON because the object is null.");
        }
        jgen.writeObject(value.getLanguageCode());
    }

}
